EXPORTS
	??0TRemConAddress@@QAE@XZ @ 1 NONAME ; TRemConAddress::TRemConAddress(void)
	??1TRemConAddress@@QAE@XZ @ 2 NONAME ; TRemConAddress::~TRemConAddress(void)
	??8TRemConAddress@@QBEHABV0@@Z @ 3 NONAME ; int TRemConAddress::operator==(class TRemConAddress const &) const
	?Addr@TRemConAddress@@QAEAAV?$TBuf8@$0BM@@@XZ @ 4 NONAME ; class TBuf8<28> & TRemConAddress::Addr(void)
	?Addr@TRemConAddress@@QBEABV?$TBuf8@$0BM@@@XZ @ 5 NONAME ; class TBuf8<28> const & TRemConAddress::Addr(void) const
	?BearerUid@TRemConAddress@@QAEAAVTUid@@XZ @ 6 NONAME ; class TUid & TRemConAddress::BearerUid(void)
	?BearerUid@TRemConAddress@@QBE?AVTUid@@XZ @ 7 NONAME ; class TUid TRemConAddress::BearerUid(void) const
	?IsNull@TRemConAddress@@QBEHXZ @ 8 NONAME ; int TRemConAddress::IsNull(void) const
	?Uid@CRemConInterfaceDetails@@QBE?AVTUid@@XZ @ 9 NONAME ; class TUid CRemConInterfaceDetails::Uid(void) const
	?NewLC@CRemConInterfaceDetails@@SAPAV1@VTUid@@W4TRemConClientType@@HPAVCRemConInterfaceBase@@ABVTDesC8@@@Z @ 10 NONAME ; class CRemConInterfaceDetails * CRemConInterfaceDetails::NewLC(class TUid, enum TRemConClientType, int, class CRemConInterfaceBase *, class TDesC8 const &)
	?Array@CRemConInterfaceDetailsArray@@QBE?AV?$TArray@PAVCRemConInterfaceDetails@@@@XZ @ 11 NONAME ; class TArray<class CRemConInterfaceDetails *> CRemConInterfaceDetailsArray::Array(void) const
	?ExternalizeL@CRemConInterfaceDetailsArray@@QAEXAAVRWriteStream@@W4TRemConClientType@@@Z @ 12 NONAME ; void CRemConInterfaceDetailsArray::ExternalizeL(class RWriteStream &, enum TRemConClientType)
	?DeleteFeatures@CRemConInterfaceDetails@@QAEXXZ @ 13 NONAME ; void CRemConInterfaceDetails::DeleteFeatures(void)
	?Interface@CRemConInterfaceDetails@@QAEAAPAVCRemConInterfaceBase@@XZ @ 14 NONAME ; class CRemConInterfaceBase * & CRemConInterfaceDetails::Interface(void)
	?InternalizeL@CRemConInterfaceDetailsArray@@SAPAV1@AAVRReadStream@@@Z @ 15 NONAME ; class CRemConInterfaceDetailsArray * CRemConInterfaceDetailsArray::InternalizeL(class RReadStream &)
	?NewL@CRemConInterfaceDetailsArray@@SAPAV1@XZ @ 16 NONAME ; class CRemConInterfaceDetailsArray * CRemConInterfaceDetailsArray::NewL(void)
	?GetRemConInterfaceFeaturesL@CRemConInterfaceDetails@@QBEXAAV?$RArray@I@@@Z @ 17 NONAME ; void CRemConInterfaceDetails::GetRemConInterfaceFeaturesL(class RArray<unsigned int> &) const
	?IsBulk@CRemConInterfaceDetails@@QBEHXZ @ 18 NONAME ; int CRemConInterfaceDetails::IsBulk(void) const
	?Type@CRemConInterfaceDetails@@QBE?AW4TRemConClientType@@XZ @ 19 NONAME ; enum TRemConClientType CRemConInterfaceDetails::Type(void) const
	?AppendL@CRemConInterfaceDetailsArray@@QAEXPAVCRemConInterfaceDetails@@@Z @ 20 NONAME ; void CRemConInterfaceDetailsArray::AppendL(class CRemConInterfaceDetails *)

